package com.jeeplus.modules.filing.constructionStage.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.filing.constructionStage.entity.ConstructionStage;
import com.jeeplus.modules.filing.constructionStage.service.ConstructionStageService;
import com.jeeplus.modules.filing.filingImages.service.FilingImagesService;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;

/**
 * 工程建设阶段Controller
 * @author qy
 * @version 2021-03-24
 */
@Controller
@RequestMapping(value = "${adminPath}/filing/constructionStage")
public class ConstructionStageController extends BaseController {

	@Autowired
	private ConstructionStageService constructionStageService;

	@Autowired
	private FilingImagesService filingImagesService;

	@ModelAttribute
	public ConstructionStage get(@RequestParam(required=false) String id) {
		ConstructionStage entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = constructionStageService.get(id);
		}
		if (entity == null){
			entity = new ConstructionStage();
		}
		return entity;
	}
	
	/**
	 * 工程建设阶段列表页面
	 */
	@RequiresPermissions("test:filing:constructionStage:list")
	@RequestMapping(value = {"list", ""})
	public String list(ConstructionStage constructionStage, Model model) {
		model.addAttribute("constructionStage", constructionStage);
		return "modules/filing/constructionStage/constructionStageList";
	}
	
	/**
	 * 工程建设阶段列表数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:constructionStage:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(ConstructionStage constructionStage, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ConstructionStage> page = constructionStageService.findPage(new Page<ConstructionStage>(request, response,-1), constructionStage);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加,工程建设阶段表单页面
	 */
	@RequiresPermissions(value={"test:filing:constructionStage:view","test:filing:constructionStage:add","test:filing:constructionStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(ConstructionStage constructionStage, Model model) {
		model.addAttribute("constructionStage", constructionStage);
		return "modules/filing/constructionStage/constructionStageForm";
	}

	
	/**
	 * 保存工程建设阶段
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:constructionStage:add","test:filing:constructionStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(ConstructionStage constructionStage, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(constructionStage);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		constructionStageService.save(constructionStage);//保存
		j.setSuccess(true);
		j.setMsg("保存工程建设阶段成功");
		return j;
	}

	/**
	 * 保存工程建设阶段
	 */
	@ResponseBody
	@RequiresPermissions(value={"test:filing:constructionStage:add","test:filing:constructionStage:edit"},logical=Logical.OR)
	@RequestMapping(value = "updateSave")
	public AjaxJson updateSave(ConstructionStage constructionStage, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(constructionStage);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		constructionStageService.save(constructionStage);//保存
		j.setSuccess(true);
		j.setMsg("保存工程建设阶段成功");
		return j;
	}


	/**
	 * 删除工程建设阶段
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:constructionStage:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(ConstructionStage constructionStage) {
		AjaxJson j = new AjaxJson();
		constructionStageService.delete(constructionStage);
		j.setMsg("删除工程建设阶段成功");
		return j;
	}
	
	/**
	 * 批量删除工程建设阶段
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:constructionStage:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			constructionStageService.delete(constructionStageService.get(id));
		}
		j.setMsg("删除工程建设阶段成功");
		return j;
	}
	
	/**
	 * 导出excel文件
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:constructionStage:export")
    @RequestMapping(value = "export")
    public AjaxJson exportFile(ConstructionStage constructionStage, HttpServletRequest request, HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "工程建设阶段"+DateUtils.getDate("yyyyMMddHHmmss")+".xlsx";
            Page<ConstructionStage> page = constructionStageService.findAllPage(new Page<ConstructionStage>(request, response, -1), constructionStage);
    		new ExportExcel("工程建设阶段", ConstructionStage.class).setDataList(page.getList()).write(response, fileName).dispose();
    		j.setSuccess(true);
    		j.setMsg("导出成功！");
    		return j;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导出工程建设阶段记录失败！失败信息："+e.getMessage());
		}
			return j;
    }

    
    @ResponseBody
    @RequestMapping(value = "detail")
	public Map<String, Object> detail(ConstructionStage constructionStage, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ConstructionStage> page = constructionStageService.findChildPage(new Page<ConstructionStage>(request, response), constructionStage);
		return getBootstrapData(page);
	}
	

	/**
	 * 导入Excel数据
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:constructionStage:import")
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			ImportExcel ei = new ImportExcel(file, 1, 0);
			List<ConstructionStage> list = ei.getDataList(ConstructionStage.class);
			for (ConstructionStage constructionStage :
					list) {
				constructionStageService.save(constructionStage);
			}
			j.setMsg( "已成功导入条工程建设阶段记录");
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入工程建设阶段失败！失败信息："+e.getMessage());
		}
		return j;
    }
	
	/**
	 * 下载导入工程建设阶段数据模板
	 */
	@ResponseBody
	@RequiresPermissions("test:filing:constructionStage:import")
    @RequestMapping(value = "import/template")
     public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
            String fileName = "工程建设阶段数据导入模板.xlsx";
    		List<ConstructionStage> list = Lists.newArrayList(); 
    		new ExportExcel("工程建设阶段数据", ConstructionStage.class, 1).setDataList(list).write(response, fileName).dispose();
    		return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "导入模板下载失败！失败信息："+e.getMessage());
		}
		return j;
    }
	

}