/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.filing.filingImages.service;

import com.google.common.collect.Lists;
import com.jeeplus.common.config.Global;
import com.jeeplus.common.utils.PropertiesLoader;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.core.web.Servlets;
import com.jeeplus.modules.filing.approvalStage.entity.ApprovalStage;
import com.jeeplus.modules.filing.approvalStage.entity.EarlyStage;
import com.jeeplus.modules.filing.approvalStage.entity.StudyStage;
import com.jeeplus.modules.filing.approvalStage.mapper.ApprovalStageMapper;
import com.jeeplus.modules.filing.approvalStage.mapper.EarlyStageMapper;
import com.jeeplus.modules.filing.approvalStage.mapper.StudyStageMapper;
import com.jeeplus.modules.filing.basicInformation.entity.BasicInformation;
import com.jeeplus.modules.filing.basicInformation.mapper.BasicInformationMapper;
import com.jeeplus.modules.filing.earlyEngineering.entity.*;
import com.jeeplus.modules.filing.earlyEngineering.mapper.*;
import com.jeeplus.modules.filing.filingImages.entity.FilingImages;
import com.jeeplus.modules.filing.filingImages.mapper.FilingImagesMapper;
import com.jeeplus.modules.filing.filingImages.utils.ZipCompressUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;

import static com.jeeplus.common.config.Global.SYS_TYPE;

/**
 * 图片管理Service
 *
 * @author qy
 * @version 2021-03-25
 */
@Service
@Transactional(readOnly = true)
public class FilingImagesService extends CrudService<FilingImagesMapper, FilingImages> {

    @Autowired
    private BasicInformationMapper basicInformationMapper;


    @Autowired
    private ApprovalStageMapper approvalStageMapper;


    @Autowired
    private EarlyStageMapper earlyStageMapper;

    @Autowired
    private StudyStageMapper studyStageMapper;

    @Autowired
    private DesignStageMapper designStageMapper;

    @Autowired
    private ReviewStageMapper reviewStageMapper;

    @Autowired
    private BiddingContractMapper biddingContractMapper;

    @Autowired
    private ApplicationForMapper applicationForMapper;

    @Autowired
    private EarlyEngineeringMapper earlyEngineeringMapper;

    /**
     * 属性文件加载对象
     */
    private static PropertiesLoader loader = new PropertiesLoader("/properties/jeeplus.properties");

    public List<FilingImages> findByProjectId(String id) {
        return mapper.findByProjectId(id);
    }



    /**
     * 通过项目id导出项目的核准附件
     *
     * @param idList
     */
    public String exportApproved(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }
        //通过id查询出所有的项目信息
        List<ApprovalStage> byIdList = approvalStageMapper.findByIdList(idList);
        //循环遍历，判断项目是否存在
        for (ApprovalStage a :
                byIdList) {
            File dirFile = null;
            List<FilingImages> filingImagesList = null;
            List<FilingImages> exportList = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();
            String approvedAnnex = a.getApprovedAnnex();
            if (null!=approvedAnnex && !"".equals(approvedAnnex)) {
                dirFile = new File(downloadPath + "/核准阶段");
                if (approvedAnnex.contains("|")) {
                    String[] split = approvedAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("核准附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(approvedAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("核准附件");
                    exportList.add(filingImages);
                }
                if (exportList.size() > 0) {
                    this.disposeFileList(exportList, dirFile.getPath());
                }
            }
        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }


    /**
     * 项目相应文件批量下载并压缩
     *
     * @param idList
     */
    public String exportStudy(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }

        List<StudyStage> allList = new ArrayList<>();
        //通过id查询出所有的项目信息
        List<StudyStage> byIdList = studyStageMapper.findAllStudy(idList);

        for (StudyStage a :
                byIdList) {
            allList.add(a);
            List<StudyStage> childList = studyStageMapper.findChildList(a);
            if (childList.size() > 0) {
                for (StudyStage b :
                        childList) {
                    allList.add(b);
                }
            }
        }

        //循环遍历，判断项目是否存在
        for (StudyStage a :
                allList) {
            File dirFile = null;
            List<FilingImages> filingImagesList = null;
            List<FilingImages> exportList = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();
            String studyAppendix = a.getStudyAppendix();
            if (null!=studyAppendix && !"".equals(studyAppendix)) {
                dirFile = new File(downloadPath + "/可研阶段");
                if (studyAppendix.contains("|")) {
                    String[] split = studyAppendix.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("可研附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(studyAppendix);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("可研附件");
                    exportList.add(filingImages);
                }
                if (exportList.size() > 0) {
                    this.disposeFileList(exportList, dirFile.getPath());
                }
            }
        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }


    /**
     * 项目相应文件批量下载并压缩
     *
     * @param idList
     */
    public String exportStudyStage(List<String> idList,String purpose) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }
        List<String> allIdList = new ArrayList<>();
        //通过id查询出
        //通过id查询出所有有关联的id
        for (String projectId : idList) {
            allIdList.add(projectId);
            BasicInformation one = basicInformationMapper.findOne(projectId);
            List<BasicInformation> childByCode = null;
            try {
                childByCode = basicInformationMapper.findChildByCode(one.getProjectCode());
            } catch (Exception e) {
                e.printStackTrace();
            }
            for (BasicInformation b :
                    childByCode) {
                allIdList.add(b.getId());
            }
        }

        //遍历项目id并查询对应数据信息
        for (String projectId : allIdList) {
            //通过id查询项目信息
            BasicInformation one = basicInformationMapper.findOne(projectId);
            String projectCode = one.getProjectCode();
            //通过项目信息获取附件信息
            List<String> byCode = mapper.findAllPurpose(projectCode);
            File dirFile = null;
            List<FilingImages> filingImagesList = null;
            List<FilingImages> exportList = new ArrayList<>();
            String downloadPath = path + "/" + one.getProjectCode();
            for (String a :
                    byCode) {
                switch (a) {
                    case "核准附件":
                        dirFile = new File(downloadPath + "/核准阶段");
                        filingImagesList = Lists.newArrayList();
                        filingImagesList = mapper.findAllUpload(one.getProjectCode(), a);
                        for (FilingImages filing :
                                filingImagesList) {
                            if (filing.getImgPath().contains("|")) {
                                String[] split = filing.getImgPath().split("\\|");
                                for (int i = 0; i < split.length; i++) {
                                    FilingImages filingImages = new FilingImages();
                                    filingImages.setImgPath(split[i]);
                                    filingImages.setProjectCode(filing.getProjectCode());
                                    filingImages.setPurpose(filing.getPurpose());
                                    exportList.add(filingImages);
                                }

                            } else {
                                exportList.add(filing);
                            }
                        }
                        this.disposeFileList(exportList, dirFile.getPath());
                        break;
                    case "可研附件":
                        dirFile = new File(downloadPath + "/可研阶段");
                        filingImagesList = Lists.newArrayList();
                        filingImagesList = mapper.findAllUpload(one.getProjectCode(), a);
                        for (FilingImages filing :
                                filingImagesList) {
                            if (filing.getImgPath().contains("|")) {
                                String[] split = filing.getImgPath().split("\\|");
                                for (int i = 0; i < split.length; i++) {
                                    FilingImages filingImages = new FilingImages();
                                    filingImages.setImgPath(split[i]);
                                    filingImages.setProjectCode(filing.getProjectCode());
                                    filingImages.setPurpose(filing.getPurpose());
                                    exportList.add(filingImages);
                                }

                            } else {
                                exportList.add(filing);
                            }
                        }
                        this.disposeFileList(exportList, dirFile.getPath());
                        break;
                    case "初设附件":
                        dirFile = new File(downloadPath + "/初设阶段");
                        break;
                }
            }

        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }


    /**
     * 处理文件信息
     *
     * @param downloadPath
     */
    public void disposeFileList(List<FilingImages> filingImages, String downloadPath) throws IOException {
        ZipCompressUtil zipCompressUtil = new ZipCompressUtil();
        String FILE_PREFIX = loader.getProperty("linux.file.store.prefix");
        if (SYS_TYPE.equals("1")) {
            for (FilingImages info : filingImages) {
                zipCompressUtil.downloadRuralProject(info.getImgPath().substring(0, info.getImgPath().lastIndexOf("/")), info.getImgPath().substring(info.getImgPath().lastIndexOf("/") + 1, info.getImgPath().length()), downloadPath);
            }
        } else {
            for (FilingImages info : filingImages) {
                zipCompressUtil.downloadRuralProject(FILE_PREFIX+info.getImgPath().substring(0, info.getImgPath().lastIndexOf("/")), info.getImgPath().substring(info.getImgPath().lastIndexOf("/") + 1, info.getImgPath().length()), downloadPath);
            }
        }

    }

    /**
     * 下载压缩文件
     *
     * @param filePath
     * @param response
     */
    public void downloadZipFile(String filePath, HttpServletResponse response) {
        File file = new File(filePath);
        //取得文件名。
        String fileName = file.getName();
        InputStream in = null;
        try {
            fileName = URLEncoder.encode(fileName, "UTF8");
            in = new FileInputStream(file);
            response.reset();//重置 响应头
            response.setCharacterEncoding("UTF-8");
            response.setContentType("application/x-download");
            response.setHeader("Content-disposition", "attachment; filename=" + fileName);

            byte[] b = new byte[1024];
            int len;
            while ((len = in.read(b)) > 0) {
                response.getOutputStream().write(b, 0, len);
            }
            in.close();
            response.getOutputStream().close();
        } catch (IOException e) {
            throw new RuntimeException(e);
        } finally {
            //路径是个文件且不为空时删除文件
            if (file.isFile() && file.exists()) {
                file.delete();
            }
        }
    }


    /**
     * 通过项目id导出项目的核准附件
     *
     * @param idList
     */
    public String exportEarlyStage(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }

        List<EarlyStage> allList = new ArrayList<>();
        //通过id查询出所有的项目信息
        List<EarlyStage> byIdList = earlyStageMapper.findAllStudy(idList);

        for (EarlyStage a :
                byIdList) {
            allList.add(a);
            List<EarlyStage> childList = earlyStageMapper.findChildList(a);
            if (childList.size() > 0) {
                for (EarlyStage b :
                        childList) {
                    allList.add(b);
                }
            }
        }
        //循环遍历，判断项目是否存在
        for (EarlyStage a :
                allList) {
            File dirFile = null;
            File dirFile2 = null;
            List<FilingImages> filingImagesList = null;
            List<FilingImages> exportList = new ArrayList<>();
            List<FilingImages> exportList2 = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();
            String approvedAnnex = a.getApprovedAnnex();
            if (null!=approvedAnnex && !"".equals(approvedAnnex)) {
                dirFile = new File(downloadPath + "/核准阶段");
                if (approvedAnnex.contains("|")) {
                    String[] split = approvedAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("核准附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(approvedAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("核准附件");
                    exportList.add(filingImages);
                }
            }
            String studyAppendix = a.getStudyAppendix();
            if (null!=studyAppendix && !"".equals(studyAppendix)) {
                dirFile2 = new File(downloadPath + "/可研阶段");
                if (studyAppendix.contains("|")) {
                    String[] split = studyAppendix.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("核准附件");
                        exportList2.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(studyAppendix);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("可研附件");
                    exportList2.add(filingImages);
                }
            }
            if (exportList.size() > 0) {
                this.disposeFileList(exportList, dirFile.getPath());
            }
            if (exportList2.size() > 0) {
                this.disposeFileList(exportList2, dirFile2.getPath());
            }
        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }


    /**
     * 通过项目id导出项目的初设阶段
     *
     * @param idList
     */
    public String exportDesignStage(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }

        List<DesignStage> allList = new ArrayList<>();
        //通过id查询出所有的项目信息
        List<DesignStage> byIdList = designStageMapper.findAll(idList);

        for (DesignStage a :
                byIdList) {
            allList.add(a);
            List<DesignStage> childList = designStageMapper.findChildList(a);
            if (childList.size() > 0) {
                for (DesignStage b :
                        childList) {
                    allList.add(b);
                }
            }
        }
        //循环遍历，判断项目是否存在
        for (DesignStage a :
                allList) {
            File dirFile = null;
            List<FilingImages> filingImagesList = null;
            List<FilingImages> exportList = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();
            String designAnnex = a.getPreDesignAnnex();
            if (null!=designAnnex && !"".equals(designAnnex)) {
                dirFile = new File(downloadPath + "/初设阶段");
                if (designAnnex.contains("|")) {
                    String[] split = designAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("初设附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(designAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("初设附件");
                    exportList.add(filingImages);
                }
            }

            if (exportList.size() > 0) {
                this.disposeFileList(exportList, dirFile.getPath());
            }

        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }


    /**
     * 通过项目id导出项目的招标与合同管理
     *
     * @param idList
     */
    public String exportBiddingContract(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }

        List<BiddingContract> allList = new ArrayList<>();
        //通过id查询出所有的项目信息
        List<BiddingContract> byIdList = biddingContractMapper.findAll(idList);

        for (BiddingContract a :
                byIdList) {
            allList.add(a);
            List<BiddingContract> childList = biddingContractMapper.findChildList(a);
            if (childList.size() > 0) {
                for (BiddingContract b :
                        childList) {
                    allList.add(b);
                }
            }
        }
        //循环遍历，判断项目是否存在
        for (BiddingContract a :
                allList) {
            File dirFile = null;
            List<FilingImages> exportList = new ArrayList<>();
            List<FilingImages> exportList2 = new ArrayList<>();
            List<FilingImages> exportList3 = new ArrayList<>();
            List<FilingImages> exportList4 = new ArrayList<>();
            List<FilingImages> exportList5 = new ArrayList<>();
            List<FilingImages> exportList6 = new ArrayList<>();
            List<FilingImages> exportList7 = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();

            String letterDesign = a.getLetterDesign();
            String disigningContract = a.getDisigningContract();
            String ownerDapartment = a.getOwnerDapartment();
            String inspectionControl = a.getInspectionControl();
            String letterAcceptance = a.getLetterAcceptance();
            String conContract = a.getConContract();
            String otherContracts = a.getOtherContracts();


            if (null!=letterDesign && !"".equals(letterDesign)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (letterDesign.contains("|")) {
                    String[] split = letterDesign.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(letterDesign);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList.add(filingImages);
                }
            }

            if (null!=disigningContract && !"".equals(disigningContract)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (disigningContract.contains("|")) {
                    String[] split = disigningContract.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList2.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(disigningContract);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList2.add(filingImages);
                }
            }

            if (null!=ownerDapartment && !"".equals(ownerDapartment)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (ownerDapartment.contains("|")) {
                    String[] split = ownerDapartment.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList3.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(ownerDapartment);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList3.add(filingImages);
                }
            }

            if (null!=inspectionControl && !"".equals(inspectionControl)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (inspectionControl.contains("|")) {
                    String[] split = inspectionControl.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList4.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(inspectionControl);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList4.add(filingImages);
                }
            }

            if (null!=letterAcceptance && !"".equals(letterAcceptance)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (letterAcceptance.contains("|")) {
                    String[] split = letterAcceptance.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList5.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(letterAcceptance);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList5.add(filingImages);
                }
            }

            if (null!=conContract && !"".equals(conContract)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (conContract.contains("|")) {
                    String[] split = conContract.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList6.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(conContract);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList6.add(filingImages);
                }
            }

            if (null!=otherContracts && !"".equals(otherContracts)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (otherContracts.contains("|")) {
                    String[] split = otherContracts.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList7.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(otherContracts);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList7.add(filingImages);
                }
            }

            if (exportList.size() > 0) {
                this.disposeFileList(exportList, dirFile.getPath());
            }
            if (exportList2.size() > 0) {
                this.disposeFileList(exportList2, dirFile.getPath());
            }
            if (exportList3.size() > 0) {
                this.disposeFileList(exportList3, dirFile.getPath());
            }
            if (exportList4.size() > 0) {
                this.disposeFileList(exportList4, dirFile.getPath());
            }
            if (exportList5.size() > 0) {
                this.disposeFileList(exportList5, dirFile.getPath());
            }
            if (exportList6.size() > 0) {
                this.disposeFileList(exportList6, dirFile.getPath());
            }
            if (exportList7.size() > 0) {
                this.disposeFileList(exportList7, dirFile.getPath());
            }

        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }


    /**
     * 通过项目id导出项目的招标与合同管理
     *
     * @param idList
     */
    public String exportApplicationFor(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }

        List<ApplicationFor> allList = new ArrayList<>();
        //通过id查询出所有的项目信息
        List<ApplicationFor> byIdList = applicationForMapper.findAll(idList);

        for (ApplicationFor a :
                byIdList) {
            allList.add(a);
            List<ApplicationFor> childList = applicationForMapper.findChildList(a);
            if (childList.size() > 0) {
                for (ApplicationFor b :
                        childList) {
                    allList.add(b);
                }
            }
        }
        //循环遍历，判断项目是否存在
        for (ApplicationFor a :
                allList) {
            File dirFile = null;
            List<FilingImages> exportList = new ArrayList<>();
            List<FilingImages> exportList2 = new ArrayList<>();
            List<FilingImages> exportList3 = new ArrayList<>();
            List<FilingImages> exportList4 = new ArrayList<>();
            List<FilingImages> exportList5 = new ArrayList<>();
            List<FilingImages> exportList6 = new ArrayList<>();
            List<FilingImages> exportList7 = new ArrayList<>();
            List<FilingImages> exportList8 = new ArrayList<>();
            List<FilingImages> exportList9 = new ArrayList<>();
            List<FilingImages> exportList10 = new ArrayList<>();
            List<FilingImages> exportList11 = new ArrayList<>();
            List<FilingImages> exportList12 = new ArrayList<>();
            List<FilingImages> exportList13 = new ArrayList<>();
            List<FilingImages> exportList14 = new ArrayList<>();
            List<FilingImages> exportList15 = new ArrayList<>();
            List<FilingImages> exportList16 = new ArrayList<>();
            List<FilingImages> exportList17 = new ArrayList<>();
            List<FilingImages> exportList18 = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();

            String landAnnex = a.getLandAnnex();
            String eiaAnnex = a.getEiaAnnex();
            String acceptanceAnnex = a.getAcceptanceAnnex();
            String replyAnnex = a.getReplyAnnex();
            String soilannex = a.getSoilannex();
            String depositAnnex = a.getDepositAnnex();
            String recordAnnex = a.getRecordAnnex();
            String siteProposalAnnex = a.getSiteProposalAnnex();
            String planningAnnex = a.getPlanningAnnex();
            String usePlanAnnex = a.getUsePlanAnnex();
            String requisitonAnnex = a.getRequisitonAnnex();
            String conLandAnnex = a.getConLandAnnex();
            String transferAnnex = a.getTransferAnnex();
            String certificateAnnex = a.getCertificateAnnex();
            String permitAnnex = a.getPermitAnnex();
            String fireProAnnex = a.getFireProAnnex();
            String fireAccAnnex = a.getFireAccAnnex();
            String estateAnnex = a.getEstateAnnex();


            if (null!=landAnnex && !"".equals(landAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (landAnnex.contains("|")) {
                    String[] split = landAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(landAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList.add(filingImages);
                }
            }

            if (null!=eiaAnnex && !"".equals(eiaAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (eiaAnnex.contains("|")) {
                    String[] split = eiaAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList2.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(eiaAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList2.add(filingImages);
                }
            }

            if (null!=acceptanceAnnex && !"".equals(acceptanceAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (acceptanceAnnex.contains("|")) {
                    String[] split = acceptanceAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList3.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(acceptanceAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList3.add(filingImages);
                }
            }

            if (null!=replyAnnex && !"".equals(replyAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (replyAnnex.contains("|")) {
                    String[] split = replyAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList4.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(replyAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList4.add(filingImages);
                }
            }

            if (null!=soilannex && !"".equals(soilannex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (soilannex.contains("|")) {
                    String[] split = soilannex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList5.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(soilannex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList5.add(filingImages);
                }
            }

            if (null!=depositAnnex && !"".equals(depositAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (depositAnnex.contains("|")) {
                    String[] split = depositAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList6.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(depositAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList6.add(filingImages);
                }
            }

            if (null!=recordAnnex && !"".equals(recordAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (recordAnnex.contains("|")) {
                    String[] split = recordAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList7.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(recordAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList7.add(filingImages);
                }
            }

            if (null!=siteProposalAnnex && !"".equals(siteProposalAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (siteProposalAnnex.contains("|")) {
                    String[] split = siteProposalAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList8.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(siteProposalAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList8.add(filingImages);
                }
            }

            if (null!=planningAnnex && !"".equals(planningAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (planningAnnex.contains("|")) {
                    String[] split = planningAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList9.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(planningAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList9.add(filingImages);
                }
            }

            if (null!=usePlanAnnex && !"".equals(usePlanAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (usePlanAnnex.contains("|")) {
                    String[] split = usePlanAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList10.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(usePlanAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList10.add(filingImages);
                }
            }

            if (null!=requisitonAnnex && !"".equals(requisitonAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (requisitonAnnex.contains("|")) {
                    String[] split = requisitonAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList11.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(requisitonAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList11.add(filingImages);
                }
            }

            if (null!=conLandAnnex && !"".equals(conLandAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (conLandAnnex.contains("|")) {
                    String[] split = conLandAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList12.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(conLandAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList12.add(filingImages);
                }
            }

            if (null!=transferAnnex && !"".equals(transferAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (transferAnnex.contains("|")) {
                    String[] split = transferAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList13.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(transferAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList13.add(filingImages);
                }
            }

            if (null!=certificateAnnex && !"".equals(certificateAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (certificateAnnex.contains("|")) {
                    String[] split = certificateAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList14.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(certificateAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList14.add(filingImages);
                }
            }

            if (null!=permitAnnex && !"".equals(permitAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (permitAnnex.contains("|")) {
                    String[] split = permitAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList15.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(permitAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList15.add(filingImages);
                }
            }

            if (null!=fireProAnnex && !"".equals(fireProAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (fireProAnnex.contains("|")) {
                    String[] split = fireProAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList16.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(fireProAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList16.add(filingImages);
                }
            }

            if (null!=fireAccAnnex && !"".equals(fireAccAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (fireAccAnnex.contains("|")) {
                    String[] split = fireAccAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList17.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(fireAccAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList17.add(filingImages);
                }
            }

            if (null!=estateAnnex && !"".equals(estateAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (estateAnnex.contains("|")) {
                    String[] split = estateAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList18.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(estateAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList18.add(filingImages);
                }
            }

            if (exportList.size() > 0) {
                this.disposeFileList(exportList, dirFile.getPath());
            }
            if (exportList2.size() > 0) {
                this.disposeFileList(exportList2, dirFile.getPath());
            }
            if (exportList3.size() > 0) {
                this.disposeFileList(exportList3, dirFile.getPath());
            }
            if (exportList4.size() > 0) {
                this.disposeFileList(exportList4, dirFile.getPath());
            }
            if (exportList5.size() > 0) {
                this.disposeFileList(exportList5, dirFile.getPath());
            }
            if (exportList6.size() > 0) {
                this.disposeFileList(exportList6, dirFile.getPath());
            }
            if (exportList7.size() > 0) {
                this.disposeFileList(exportList7, dirFile.getPath());
            }
            if (exportList8.size() > 0) {
                this.disposeFileList(exportList8, dirFile.getPath());
            }
            if (exportList9.size() > 0) {
                this.disposeFileList(exportList9, dirFile.getPath());
            }
            if (exportList10.size() > 0) {
                this.disposeFileList(exportList10, dirFile.getPath());
            }
            if (exportList11.size() > 0) {
                this.disposeFileList(exportList11, dirFile.getPath());
            }
            if (exportList12.size() > 0) {
                this.disposeFileList(exportList12, dirFile.getPath());
            }
            if (exportList13.size() > 0) {
                this.disposeFileList(exportList13, dirFile.getPath());
            }
            if (exportList14.size() > 0) {
                this.disposeFileList(exportList14, dirFile.getPath());
            }
            if (exportList15.size() > 0) {
                this.disposeFileList(exportList15, dirFile.getPath());
            }
            if (exportList16.size() > 0) {
                this.disposeFileList(exportList16, dirFile.getPath());
            }
            if (exportList17.size() > 0) {
                this.disposeFileList(exportList17, dirFile.getPath());
            }
            if (exportList18.size() > 0) {
                this.disposeFileList(exportList18, dirFile.getPath());
            }
            

        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }

    /**
     * 通过项目id导出项目的初设阶段
     *
     * @param idList
     */
    public String exportEarlyEngineering(List<String> idList) throws Exception {
        //设置下载的压缩包名（固定字符+时间戳）
        long timeMillis = System.currentTimeMillis();
        String fileLocality = "项目附件_" + timeMillis;
        //判定当前系统
        String path = Global.getPath();
        path = path + "/" + fileLocality;
        //检查该路径对应的目录是否存在. 如果不存在则创建目录
        File dir = new File(path);
        if (!dir.exists()) {
            dir.mkdirs();
        }

        List<EarlyEngineering> allList = new ArrayList<>();
        //通过id查询出所有的项目信息
        List<EarlyEngineering> byIdList = earlyEngineeringMapper.findAll(idList);

        for (EarlyEngineering a :
                byIdList) {
            allList.add(a);
            List<EarlyEngineering> childList = earlyEngineeringMapper.findChildList(a);
            if (childList.size() > 0) {
                for (EarlyEngineering b :
                        childList) {
                    allList.add(b);
                }
            }
        }
        //循环遍历，判断项目是否存在
        for (EarlyEngineering a :
                allList) {
            File dirFile = null;
            File dirFile2 = null;
            File dirFile3 = null;
            File dirFile4 = null;
            List<FilingImages> filingImagesList = null;
            List<FilingImages> exportList = new ArrayList<>();
            List<FilingImages> exportList2 = new ArrayList<>();
            List<FilingImages> exportList3 = new ArrayList<>();
            List<FilingImages> exportList4 = new ArrayList<>();
            List<FilingImages> exportList5 = new ArrayList<>();
            List<FilingImages> exportList6 = new ArrayList<>();
            List<FilingImages> exportList7 = new ArrayList<>();
            List<FilingImages> exportList8 = new ArrayList<>();
            List<FilingImages> exportList9  = new ArrayList<>();
            List<FilingImages> exportList10  = new ArrayList<>();
            List<FilingImages> exportList11  = new ArrayList<>();
            List<FilingImages> exportList12 = new ArrayList<>();
            List<FilingImages> exportList13 = new ArrayList<>();
            List<FilingImages> exportList14 = new ArrayList<>();
            List<FilingImages> exportList15 = new ArrayList<>();
            List<FilingImages> exportList16 = new ArrayList<>();
            List<FilingImages> exportList17 = new ArrayList<>();
            List<FilingImages> exportList18 = new ArrayList<>();
            List<FilingImages> exportList19 = new ArrayList<>();
            List<FilingImages> exportList20 = new ArrayList<>();
            List<FilingImages> exportList21 = new ArrayList<>();
            List<FilingImages> exportList22 = new ArrayList<>();
            List<FilingImages> exportList23 = new ArrayList<>();
            List<FilingImages> exportList24 = new ArrayList<>();
            List<FilingImages> exportList25 = new ArrayList<>();
            List<FilingImages> exportList26 = new ArrayList<>();
            String downloadPath = path + "/" + a.getProjectCode();

            String designAnnex = a.getPreDesignAnnex();
            String letterDesign = a.getLetterDesign();
            String disigningContract = a.getDisigningContract();
            String ownerDapartment = a.getOwnerDapartment();
            String inspectionControl = a.getInspectionControl();
            String letterAcceptance = a.getLetterAcceptance();
            String conContract = a.getConContract();
            String otherContracts = a.getOtherContracts();
            String landAnnex = a.getLandAnnex();
            String eiaAnnex = a.getEiaAnnex();
            String acceptanceAnnex = a.getAcceptanceAnnex();
            String replyAnnex = a.getReplyAnnex();
            String soilannex = a.getSoilannex();
            String depositAnnex = a.getDepositAnnex();
            String recordAnnex = a.getRecordAnnex();
            String siteProposalAnnex = a.getSiteProposalAnnex();
            String planningAnnex = a.getPlanningAnnex();
            String usePlanAnnex = a.getUsePlanAnnex();
            String requisitonAnnex = a.getRequisitonAnnex();
            String conLandAnnex = a.getConLandAnnex();
            String transferAnnex = a.getTransferAnnex();
            String certificateAnnex = a.getCertificateAnnex();
            String permitAnnex = a.getPermitAnnex();
            String fireProAnnex = a.getFireProAnnex();
            String fireAccAnnex = a.getFireAccAnnex();
            String estateAnnex = a.getEstateAnnex();


            if (null!=designAnnex && !"".equals(designAnnex)) {
                dirFile3 = new File(downloadPath + "/初设阶段");
                if (designAnnex.contains("|")) {
                    String[] split = designAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("初设附件");
                        exportList.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(designAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("初设附件");
                    exportList.add(filingImages);
                }
            }

            if (null!=letterDesign && !"".equals(letterDesign)) {
                dirFile2 = new File(downloadPath + "/招标与合同管理");
                if (letterDesign.contains("|")) {
                    String[] split = letterDesign.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList2.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(letterDesign);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList2.add(filingImages);
                }
            }

            if (null!=disigningContract && !"".equals(disigningContract)) {
                dirFile2 = new File(downloadPath + "/招标与合同管理");
                if (disigningContract.contains("|")) {
                    String[] split = disigningContract.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList3.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(disigningContract);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList3.add(filingImages);
                }
            }

            if (null!=ownerDapartment && !"".equals(ownerDapartment)) {
                dirFile = new File(downloadPath + "/招标与合同管理");
                if (ownerDapartment.contains("|")) {
                    String[] split = ownerDapartment.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList4.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(ownerDapartment);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList4.add(filingImages);
                }
            }

            if (null!=inspectionControl && !"".equals(inspectionControl)) {
                dirFile2 = new File(downloadPath + "/招标与合同管理");
                if (inspectionControl.contains("|")) {
                    String[] split = inspectionControl.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList5.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(inspectionControl);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList5.add(filingImages);
                }
            }

            if (null!=letterAcceptance && !"".equals(letterAcceptance)) {
                dirFile2 = new File(downloadPath + "/招标与合同管理");
                if (letterAcceptance.contains("|")) {
                    String[] split = letterAcceptance.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList6.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(letterAcceptance);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList6.add(filingImages);
                }
            }

            if (null!=conContract && !"".equals(conContract)) {
                dirFile2 = new File(downloadPath + "/招标与合同管理");
                if (conContract.contains("|")) {
                    String[] split = conContract.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList7.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(conContract);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList7.add(filingImages);
                }
            }

            if (null!=otherContracts && !"".equals(otherContracts)) {
                dirFile2 = new File(downloadPath + "/招标与合同管理");
                if (otherContracts.contains("|")) {
                    String[] split = otherContracts.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose("招标与合同管理附件");
                        exportList8.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(otherContracts);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose("招标与合同管理附件");
                    exportList8.add(filingImages);
                }
            }

            if (null!=landAnnex && !"".equals(landAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (landAnnex.contains("|")) {
                    String[] split = landAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList9.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(landAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList9.add(filingImages);
                }
            }

            if (null!=eiaAnnex && !"".equals(eiaAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (eiaAnnex.contains("|")) {
                    String[] split = eiaAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList10.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(eiaAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList10.add(filingImages);
                }
            }

            if (null!=acceptanceAnnex && !"".equals(acceptanceAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (acceptanceAnnex.contains("|")) {
                    String[] split = acceptanceAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList11.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(acceptanceAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList11.add(filingImages);
                }
            }

            if (null!=replyAnnex && !"".equals(replyAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (replyAnnex.contains("|")) {
                    String[] split = replyAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList12.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(replyAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList12.add(filingImages);
                }
            }

            if (null!=soilannex && !"".equals(soilannex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (soilannex.contains("|")) {
                    String[] split = soilannex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList13.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(soilannex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList13.add(filingImages);
                }
            }

            if (null!=depositAnnex && !"".equals(depositAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (depositAnnex.contains("|")) {
                    String[] split = depositAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList14.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(depositAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList14.add(filingImages);
                }
            }

            if (null!=recordAnnex && !"".equals(recordAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (recordAnnex.contains("|")) {
                    String[] split = recordAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList15.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(recordAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList15.add(filingImages);
                }
            }

            if (null!=siteProposalAnnex && !"".equals(siteProposalAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (siteProposalAnnex.contains("|")) {
                    String[] split = siteProposalAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList16.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(siteProposalAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList16.add(filingImages);
                }
            }

            if (null!=planningAnnex && !"".equals(planningAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (planningAnnex.contains("|")) {
                    String[] split = planningAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList17.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(planningAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList17.add(filingImages);
                }
            }

            if (null!=usePlanAnnex && !"".equals(usePlanAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (usePlanAnnex.contains("|")) {
                    String[] split = usePlanAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList18.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(usePlanAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList18.add(filingImages);
                }
            }

            if (null!=requisitonAnnex && !"".equals(requisitonAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (requisitonAnnex.contains("|")) {
                    String[] split = requisitonAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList19.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(requisitonAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList19.add(filingImages);
                }
            }

            if (null!=conLandAnnex && !"".equals(conLandAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (conLandAnnex.contains("|")) {
                    String[] split = conLandAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList20.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(conLandAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList20.add(filingImages);
                }
            }

            if (null!=transferAnnex && !"".equals(transferAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (transferAnnex.contains("|")) {
                    String[] split = transferAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList21.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(transferAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList21.add(filingImages);
                }
            }

            if (null!=certificateAnnex && !"".equals(certificateAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (certificateAnnex.contains("|")) {
                    String[] split = certificateAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList22.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(certificateAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList22.add(filingImages);
                }
            }

            if (null!=permitAnnex && !"".equals(permitAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (permitAnnex.contains("|")) {
                    String[] split = permitAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList23.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(permitAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList23.add(filingImages);
                }
            }

            if (null!=fireProAnnex && !"".equals(fireProAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (fireProAnnex.contains("|")) {
                    String[] split = fireProAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList24.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(fireProAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList24.add(filingImages);
                }
            }

            if (null!=fireAccAnnex && !"".equals(fireAccAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (fireAccAnnex.contains("|")) {
                    String[] split = fireAccAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList25.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(fireAccAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList25.add(filingImages);
                }
            }

            if (null!=estateAnnex && !"".equals(estateAnnex)) {
                dirFile = new File(downloadPath + "/报建审批");
                if (estateAnnex.contains("|")) {
                    String[] split = estateAnnex.split("\\|");
                    for (int i = 0; i < split.length; i++) {
                        FilingImages filingImages = new FilingImages();
                        filingImages.setImgPath(split[i]);
                        filingImages.setProjectCode(a.getProjectCode());
                        filingImages.setPurpose(" 报建审批附件");
                        exportList26.add(filingImages);
                    }
                } else {
                    FilingImages filingImages = new FilingImages();
                    filingImages.setImgPath(estateAnnex);
                    filingImages.setProjectCode(a.getProjectCode());
                    filingImages.setPurpose(" 报建审批附件");
                    exportList26.add(filingImages);
                }
            }

            if (exportList.size() > 0) {
                this.disposeFileList(exportList, dirFile3.getPath());
            }

            if (exportList2.size() > 0) {
                this.disposeFileList(exportList2, dirFile2.getPath());
            }
            if (exportList3.size() > 0) {
                this.disposeFileList(exportList3, dirFile2.getPath());
            }
            if (exportList4.size() > 0) {
                this.disposeFileList(exportList4, dirFile2.getPath());
            }
            if (exportList5.size() > 0) {
                this.disposeFileList(exportList5, dirFile2.getPath());
            }
            if (exportList6.size() > 0) {
                this.disposeFileList(exportList6, dirFile2.getPath());
            }
            if (exportList7.size() > 0) {
                this.disposeFileList(exportList7, dirFile2.getPath());
            }
            if (exportList8.size() > 0) {
                this.disposeFileList(exportList8, dirFile2.getPath());
            }
            if (exportList9.size() > 0) {
                this.disposeFileList(exportList9, dirFile.getPath());
            }
            if (exportList10.size() > 0) {
                this.disposeFileList(exportList10, dirFile.getPath());
            }
            if (exportList11.size() > 0) {
                this.disposeFileList(exportList11, dirFile.getPath());
            }
            if (exportList12.size() > 0) {
                this.disposeFileList(exportList12, dirFile.getPath());
            }
            if (exportList13.size() > 0) {
                this.disposeFileList(exportList13, dirFile.getPath());
            }
            if (exportList14.size() > 0) {
                this.disposeFileList(exportList14, dirFile.getPath());
            }
            if (exportList15.size() > 0) {
                this.disposeFileList(exportList15, dirFile.getPath());
            }
            if (exportList16.size() > 0) {
                this.disposeFileList(exportList16, dirFile.getPath());
            }
            if (exportList17.size() > 0) {
                this.disposeFileList(exportList17, dirFile.getPath());
            }
            if (exportList18.size() > 0) {
                this.disposeFileList(exportList18, dirFile.getPath());
            }
            if (exportList19.size() > 0) {
                this.disposeFileList(exportList19, dirFile.getPath());
            }
            if (exportList20.size() > 0) {
                this.disposeFileList(exportList20, dirFile.getPath());
            }
            if (exportList21.size() > 0) {
                this.disposeFileList(exportList21, dirFile.getPath());
            }
            if (exportList22.size() > 0) {
                this.disposeFileList(exportList22, dirFile.getPath());
            }
            if (exportList23.size() > 0) {
                this.disposeFileList(exportList23, dirFile.getPath());
            }
            if (exportList24.size() > 0) {
                this.disposeFileList(exportList24, dirFile.getPath());
            }
            if (exportList25.size() > 0) {
                this.disposeFileList(exportList25, dirFile.getPath());
            }
            if (exportList26.size() > 0) {
                this.disposeFileList(exportList26, dirFile.getPath());
            }

        }
        //处理完之后进行打包压缩并删除之前的文件
        ZipCompressUtil zipUtil = new ZipCompressUtil();
        File resultFile = new File(path);
        File file = zipUtil.zipCompress(resultFile, true);
        return file.getPath();
    }
}